referrerpolicy=no-referrer-when-downgrade

Cid

Type Alias Cid 

pub type Cid = Cid<64>;
A Cid that contains a multihash with an allocated size of 512 bits.

This is the same digest size the default multihash code table has.

If you need a CID that is generic over its digest size, use [CidGeneric] instead.

Aliased Type

pub struct Cid { /* private fields */ }